@@ -595,7 +595,7 @@ cgmvariables <- function(inputdirectory,
 #J-index
     cgmupload["j_index",f] <- 
       0.001 * (base::mean(table$sensorglucose, na.rm = T) + 
-                 stats::sd(table$sensorglucose, na.rm = T))^2
+                 stats::sd(table$sensorglucose, na.rm = T))
 # CONGA    
     n <- (congan * 3600)
     conga.times <- table$timestamp + n
