@@ -61,8 +61,8 @@ cleandata <- function(inputdirectory,
       print(basename(files[f]))
     }
     ext <- tools::file_ext(files[f])
-    enc <- base::as.character(readr::guess_encoding(files[f])[1, 1])
     if (ext == "txt") {
+      enc <- base::as.character(readr::guess_encoding(files[f])[1, 1])
       table <- utils::read.table(files[f],
         sep = "\t",
         skipNul = TRUE,
@@ -156,8 +156,8 @@ cleandata <- function(inputdirectory,
       } else {
         id <- sub(ext, "", basename(files[f]))
       }
-      base::colnames(table) <- table[base::which(table[, 3] == "Sensor") + 1, ]
-      table <- table[-c(1:(base::which(table[, 3] == "Sensor") + 1)), ]
+      base::colnames(table) <- table[base::which(table[, 3] == "Sensor")[1] + 1, ]
+      table <- table[-c(1:(base::which(table[, 3] == "Sensor")[1] + 1)), ]
       table$timestamp <- base::paste(table$Date, table$Time)
       table$timestamp <- base::gsub(".{3}$", "", table$timestamp)
       table <- table[, base::grep("timestamp|Sensor Glucose", colnames(table))]
